

Changelog
=========

(Note that there will be many small releases, as we attempt to always keep
the package up-to-date through pip.)

0.3.2
-----

* Added MANIFEST.in for easier distribution.

0.3.1
-----

* Fixing setup.py bugs with README.md and CHANGES.md file paths for long description.
* ``CropObject.join()`` now warns before exiting when the other CropObject
  is from a different document.
* ``CropObject`` global namespace can now be set as well, through
  ``CropObject.set_dataset()``
* Updated README to describe the tests situation.


0.3.0
-----

First public release.

